@@ -7,14 +7,14 @@ use Module::Build;
 Module::Build->new(
     module_name       => 'Finance::YahooJPN::Quote',
     dist_version_from => 'Quote.pm',
-    dist_author       => 'Masanori HATA <http://www.mihr.net> (Saitama, JAPAN)',
+    dist_author       => 'Masanori HATA <http://www.mihr.net/> (Saitama, JAPAN)',
     dist_abstract     => 'For fetching historical stock quotes in Japan from Yahoo! Japan Finance.',
     license           => 'perl',
     requires          => {
         'perl'         => '5.14.0',
     },
     recommends        => {
-        'perl'         => '5.14.2',
+        'perl'         => '5.18.2',
     },
     pm_files          => {
         'Quote.pm'   => 'lib/Finance/YahooJPN/Quote.pm',
